from os.path import expanduser
from time import sleep
from app import application

class application(application):
    name="VLC"

    def togglescreen(self):
        """toggle fullscreen mode"""
        state=self.isfullscreen
        self.tell("fullscreen")
        while self.isfullscreen==state:
            sleep(0.01) # wait togglescreen animation
            if not self.frontmost:
                self.activate()
        return self

    @property
    def isfullscreen(self):
        """return true is VLC is fullscreen"""
        return self.tell("""
tell front window to return miniaturizable
""").strip()=="false"

    def fullscreen(self):
        """Enter VLC fullscreen mode"""
        self.activate()
        if not self.isfullscreen:
            self.togglescreen()
        return self

    def normalscreen(self):
        """Exit VLC fullscreen mode"""
        self.activate()
        if self.isfullscreen:
            self.togglescreen()
        return self

    @property
    def playing(self):
        """return True if VLC playing"""
        return self.active and self.app.playing()

    def open(self,f):
        """return file in VLC"""
        self.app.open(expanduser(f))
        return self

    def mute(self):
        """mute VLC"""
        self.app.mute()
        return self

    @property
    def muted(self):
        """muted VLC"""
        return self.app.muted()

    def play(self):
        """play VLC"""
        self.app.play()
        return self

    def pause(self):
        """pause VLC"""
        self.app.pause()
        return self

    def stop(self):
        """stop VLC"""
        self.app.stop()
        return self

    def volumeDown(self, repeat=1):
        self.tell("""
repeat %s times
    volumeDown
end repeat
""" % repeat)
        return self

    def volumeUp(self, repeat=1):
        self.tell("""
repeat %s times
    volumeUp
end repeat
""" % repeat)
        return self

    @property
    def volume(self):
        """return volume 0..512"""
        return int(self.tell("return audio volume"))

    @volume.setter
    def volume(self, v):
        """set volume 0..512"""
        self.tell("set audio volume to %s" % v)